==> img0ch-2.1.18.zip: img0ch/_template/default/t_form.cs <==
<html>
<head>
<title><?cs var:html_escape(BBS_TITLE) ?>̃Xbh쐬tH[</title>
<meta http-equiv="Content-Type" content="text/html; charset=Shift_JIS">
<meta http-equiv="Content-Script-Type" content="text/javascript">
<meta http-equiv="Content-Style-Type" content="text/css">
<meta name="VERSION" content="<?cs var:html_escape(VERSION) ?>">
<script src="<?cs var:html_escape(StaticURI) ?>/js/jquery-1.1.js?v=<?cs var:html_escape(SecuredVersion) ?>"></script>
<script src="<?cs var:html_escape(StaticURI) ?>/js/jquery/cookie.js?v=<?cs var:html_escape(SecuredVersion) ?>"></script>
<script src="<?cs var:html_escape(StaticURI) ?>/js/img0ch/app.js?v=<?cs var:html_escape(SecuredVersion) ?>" charset="UTF-8"></script>
<script type="text/javascript">
//<!--
var app = Img0ch.App;
app.setBBS("<?cs var:html_escape(BBS) ?>");
app.setBBSURI("<?cs var:html_escape(BBSURI) ?>");
app.setCGIURI("<?cs var:html_escape(CGIURI) ?>");
app.setStaticURI("<?cs var:html_escape(StaticURI) ?>");
app.initForm("<?cs var:html_escape(BBS_COOKIE_PATH) ?>");
//-->
</script>
<style type="text/css">
<!--
.clear { clear: both; }
.icon-align { vertical-align: top; }
.image { border: none; float: left; }
-->
</style>
<?cs var:META ?>
</head>

<body bgcolor="<?cs var:html_escape(BBS_BG_COLOR) ?>" text="<?cs var:html_escape(BBS_TEXT_COLOR) ?>" link="<?cs var:html_escape(BBS_LINK_COLOR) ?>" alink="<?cs var:html_escape(BBS_ALINK_COLOR) ?>" vlink="<?cs var:html_escape(BBS_VLINK_COLOR) ?>" background="<?cs var:html_escape(BBS_BG_PICTURE) ?>">

<center>
<a name="top" />
<?cs if:BBS_TITLE_PICTURE ?><?cs if:BBS_TITLE_LINK ?><a href="<?cs var:html_escape(BBS_TITLE_LINK) ?>"><img src="<?cs  var:html_escape(BBS_TITLE_PICTURE) ?>" border="0" /></a><?cs else ?><img src="<?cs var:html_escape(BBS_TITLE_PICTURE) ?>" border="0" /><?cs /if ?>
<?cs /if ?>

<a name="info" />
<table border="1" cellspacing="7" cellpadding="3" width="95%" bgcolor="<?cs var:html_escape(BBS_MENU_COLOR) ?>">
 <tr>
  <td>
   <table border="0" width="100%">
    <tr>
     <td>
      <b><big><?cs var:html_escape(BBS_SUBTITLE) ?></big></b>
     </td>
     <td align=right>
      <a href=#menu></a> <a href=#1></a>
     </td>
    </tr>
    <tr>
     <td colspan="2">
      <?cs var:HEAD ?>
     </td>
    </tr>
   </table>
  </td>
 </tr>
 <tr>
  <td align="center">
   <a href="../index.html" Target=_blank><small><b>fꗗ</b></small></a>
  </td>
 </tr>
</table>
<br>

<?cs if:Banner ?><table border="1" cellspacing="7" cellpadding="3" width="95%" bgcolor="#ccffcc" align="center"><?cs var:Banner ?></table><br><?cs /if ?>

<a name="thread" />
<table border="1" cellspacing="7" cellpadding="3" width="95%" bgcolor="<?cs var:html_escape(BBS_MENU_COLOR) ?>">
 <tr>
  <td>
   <b>XbhVK쐬</b><br><center>
   <form class="comment" method="POST" action="<?cs var:html_escape(CGIURI) ?>/bbs.cgi" enctype="multipart/form-data">
   <input type="hidden" name="bbs" value="<?cs var:html_escape(BBS) ?>">
   <input type="hidden" name="time" value="<?cs var:html_escape(TimeStamp) ?>">
    <table border=0>
     <tr>
      <td>
        ^CgF<input type="text" name="subject" size="25">@<input type="submit" value="VKXbh쐬"><br>
        O<font size=1>iȗj</font>F<input type="text" name="FROM" size=19 value="">
       E-mail<font size=1>iȗj</font>F<input type="text" name="mail" size=19 value=""><br>
       <?cs if:UploadableFromThread ?>摜F<input type="file" name="file" size="80"><br><?cs /if ?>
       <?cs if:Icon ?>ACRF<select name="icon"><option value="" selected>Ȃ</option>
       <?cs each:item = Icons ?><option value="<?cs var:item.id ?>"><?cs var:item.name ?></option>
       <?cs /each ?></select><br><?cs /if ?>
       <textarea rows=5 cols=64 wrap=off name="MESSAGE"></textarea>
       <?cs if:UploadableFromThread ?><br>폜pXF<input type="password" name="pass"><?cs /if ?>
      </td>
     </tr>
    </table>
   </form>
  </center>
  <?cs var:html_escape(VERSION) ?>
 </td>
</tr>
</table>
</center>
</body>
</html>

==> img0ch-3.0.0.zip: img0ch/_template/default/t_form.cs <==
<html>
<head>
<title><?cs var:html_escape(BBS_TITLE) ?>̃Xbh쐬tH[</title>
<meta http-equiv="Content-Type" content="text/html; charset=Shift_JIS">
<meta http-equiv="Content-Script-Type" content="text/javascript">
<meta http-equiv="Content-Style-Type" content="text/css">
<meta name="VERSION" content="<?cs var:html_escape(VERSION) ?>">
<script src="<?cs var:html_escape(StaticURI) ?>/js/img0ch.js" charset="UTF-8"></script>
<script type="text/javascript">
//<!--
var app = Img0ch.App;
app.setBBS("<?cs var:html_escape(BBS) ?>");
app.setBBSURI("<?cs var:html_escape(BBSURI) ?>");
app.setCGIURI("<?cs var:html_escape(CGIURI) ?>");
app.setStaticURI("<?cs var:html_escape(StaticURI) ?>");
app.initForm("<?cs var:html_escape(BBS_COOKIE_PATH) ?>");
//-->
</script>
<style type="text/css">
<!--
.clear { clear: both; }
.icon-align { vertical-align: top; }
.image { border: none; float: left; }
-->
</style>
<?cs var:META ?>
</head>

<body bgcolor="<?cs var:html_escape(BBS_BG_COLOR) ?>" text="<?cs var:html_escape(BBS_TEXT_COLOR) ?>" link="<?cs var:html_escape(BBS_LINK_COLOR) ?>" alink="<?cs var:html_escape(BBS_ALINK_COLOR) ?>" vlink="<?cs var:html_escape(BBS_VLINK_COLOR) ?>" background="<?cs var:html_escape(BBS_BG_PICTURE) ?>">

<center>
<a name="top" />
<?cs if:BBS_TITLE_PICTURE ?><?cs if:BBS_TITLE_LINK ?><a href="<?cs var:html_escape(BBS_TITLE_LINK) ?>"><img src="<?cs  var:html_escape(BBS_TITLE_PICTURE) ?>" border="0" /></a><?cs else ?><img src="<?cs var:html_escape(BBS_TITLE_PICTURE) ?>" border="0" /><?cs /if ?>
<?cs /if ?>

<a name="info" />
<table border="1" cellspacing="7" cellpadding="3" width="95%" bgcolor="<?cs var:html_escape(BBS_MENU_COLOR) ?>">
 <tr>
  <td>
   <table border="0" width="100%">
    <tr>
     <td>
      <b><big><?cs var:html_escape(BBS_SUBTITLE) ?></big></b>
     </td>
     <td align=right>
      <a href=#menu></a> <a href=#1></a>
     </td>
    </tr>
    <tr>
     <td colspan="2">
      <?cs var:HEAD ?>
     </td>
    </tr>
   </table>
  </td>
 </tr>
 <tr>
  <td align="center">
   <a href="../index.html" Target=_blank><small><b>fꗗ</b></small></a>
  </td>
 </tr>
</table>
<br>

<?cs if:Banner ?><table border="1" cellspacing="7" cellpadding="3" width="95%" bgcolor="#ccffcc" align="center"><tr><td><?cs var:Banner ?></td></tr></table><br><?cs /if ?>

<a name="thread" />
<table border="1" cellspacing="7" cellpadding="3" width="95%" bgcolor="<?cs var:html_escape(BBS_MENU_COLOR) ?>">
 <tr>
  <td>
   <b>XbhVK쐬</b><br><center>
   <form class="comment" method="POST" action="<?cs var:html_escape(CGIURI) ?>/bbs.cgi" enctype="multipart/form-data">
   <input type="hidden" name="bbs" value="<?cs var:html_escape(BBS) ?>">
   <input type="hidden" name="time" value="<?cs var:html_escape(TimeStamp) ?>">
    <table border=0>
     <tr>
      <td>
        ^CgF<input type="text" name="subject" size="25">@<input type="submit" value="VKXbh쐬"><br>
        O<font size=1>iȗj</font>F<input type="text" name="FROM" size=19 value="">
       E-mail<font size=1>iȗj</font>F<input type="text" name="mail" size=19 value=""><br>
       <?cs if:UploadableFromThread ?>摜F<input type="file" name="file" size="80"><br><?cs /if ?>
       <?cs if:Icon ?>ACRF<select name="icon"><option value="" selected>Ȃ</option>
       <?cs each:item = Icons ?><option value="<?cs var:item.id ?>"><?cs var:item.name ?></option>
       <?cs /each ?></select><br><?cs /if ?>
       <textarea rows=5 cols=64 wrap=off name="MESSAGE"></textarea>
       <?cs if:UploadableFromThread ?><br>폜pXF<input type="password" name="pass"><?cs /if ?>
      </td>
     </tr>
    </table>
   </form>
  </center>
  <?cs var:html_escape(VERSION) ?>
 </td>
</tr>
</table>
</center>
</body>
</html>
